pub enum BindingType {
Uniform,
Storage {
read_only: bool,
},
Texture {
filterable: bool,
},
Texture3dFloat {
filterable: bool,
},
Texture3dUint,
StorageTexture3dWrite {
format: TextureFormat,
},
DepthTexture,
Sampler {
comparison: bool,
},
}Expand description
What kind of resource a binding slot holds.
Variants
Uniform
A uniform buffer.
Storage
A storage buffer.
Texture
A sampled 2-D texture.
Fields
Texture3dFloat
A sampled 3-D floating-point texture.
Texture3dUint
A sampled 3-D unsigned-integer texture.
StorageTexture3dWrite
A write-only 3-D storage texture used by compute-generated fields.
Fields

format: TextureFormatPortable storage format shared by the layout and texture.
DepthTexture
A depth texture sampled for comparison or raw reads.
Sampler
A sampler.